@@ -62,15 +62,22 @@ class _NodePool:
     disk_type: Optional[str] = None
     gpu: int = 0
     gpu_model: Optional[str] = None
-    is_tpu_enabled: bool = False
     is_preemptible: bool = False
     idle_size: int = 0
 
 
+@rewrite_module
+@dataclass(frozen=True)
+class _StorageInstance:
+    name: Optional[str] = None
+    size_mb: Optional[int] = None
+
+
 @rewrite_module
 @dataclass(frozen=True)
 class _Storage:
     description: str
+    instances: List[_StorageInstance]
 
 
 @rewrite_module
@@ -212,13 +219,19 @@ def _node_pool_from_api(payload: Dict[str, Any]) -> _NodePool:
         disk_size_gb=payload["disk_size_gb"],
         gpu=payload.get("gpu", 0),
         gpu_model=payload.get("gpu_model"),
-        is_tpu_enabled=payload.get("is_tpu_enabled", False),
         is_preemptible=payload.get("is_preemptible", False),
     )
 
 
 def _storage_from_api(payload: Dict[str, Any]) -> _Storage:
-    return _Storage(description=payload["description"])
+    return _Storage(
+        description=payload["description"],
+        instances=[_storage_instance_from_api(p) for p in payload.get("instances", ())],
+    )
+
+
+def _storage_instance_from_api(payload: Dict[str, Any]) -> _StorageInstance:
+    return _StorageInstance(name=payload.get("name"), size_mb=payload.get("size_mb"))
 
 
 def _serialize_resource_preset(name: str, preset: Preset) -> Dict[str, Any]:
