@@ -14,9 +14,11 @@ def test_module_for_public_names() -> None:
             # Default API url
             continue
         if hasattr(obj, "__module__"):
-            # objects from typing are public type hint aliases,
-            # e.g. Callable[...]
             assert obj.__module__ in (
                 "neuro_sdk",
+                # objects from typing are public type hint aliases,
+                # e.g. Callable[...]
                 "typing",
+                # We re-export entities from admin client
+                "neuro_admin_client.entities",
             ), f"{obj}.__module__ == {obj.__module__}, expected neuro_sdk"
